@@ -1,10 +1,8 @@
+/* A Bison parser, made by GNU Bison 2.5.  */
 
-/* A Bison parser, made by GNU Bison 2.4.1.  */
-
-/* Skeleton interface for Bison's Yacc-like parsers in C
+/* Bison interface for Yacc-like parsers in C
    
-      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
-   Free Software Foundation, Inc.
+      Copyright (C) 1984, 1989-1990, 2000-2011 Free Software Foundation, Inc.
    
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -69,29 +67,31 @@
      K_PRE = 285,
      K_PROCESSING = 286,
      K_RENAME = 287,
-     K_SELECT = 288,
-     K_SET = 289,
-     K_START = 290,
-     K_START_ARCHIVE = 291,
-     K_START_CONFIG = 292,
-     K_TABLE = 293,
-     K_TO = 294,
-     K_TRANSACTION = 295,
-     K_UPDATE = 296,
-     K_VACUUM = 297,
-     K_VALUES = 298,
-     K_WHERE = 299,
-     T_COPYDATA = 300,
-     T_COPYDATA_PART = 301,
-     T_COPYEND = 302,
-     T_IDENT = 303,
-     T_LITERAL = 304,
-     T_LITERAL_PART = 305,
-     T_NUMBER = 306,
-     T_TRACKING_FUNCTION = 307,
-     T_FINISH_FUNCTION = 308,
-     T_SEQSETVAL_FUNCTION = 309,
-     T_PGSETVAL_FUNCTION = 310
+     K_REPLICA = 288,
+     K_SELECT = 289,
+     K_SESSION_ROLE = 290,
+     K_SET = 291,
+     K_START = 292,
+     K_START_ARCHIVE = 293,
+     K_START_CONFIG = 294,
+     K_TABLE = 295,
+     K_TO = 296,
+     K_TRANSACTION = 297,
+     K_UPDATE = 298,
+     K_VACUUM = 299,
+     K_VALUES = 300,
+     K_WHERE = 301,
+     T_COPYDATA = 302,
+     T_COPYDATA_PART = 303,
+     T_COPYEND = 304,
+     T_IDENT = 305,
+     T_LITERAL = 306,
+     T_LITERAL_PART = 307,
+     T_NUMBER = 308,
+     T_TRACKING_FUNCTION = 309,
+     T_FINISH_FUNCTION = 310,
+     T_SEQSETVAL_FUNCTION = 311,
+     T_PGSETVAL_FUNCTION = 312
    };
 #endif
 /* Tokens.  */
@@ -125,29 +125,31 @@
 #define K_PRE 285
 #define K_PROCESSING 286
 #define K_RENAME 287
-#define K_SELECT 288
-#define K_SET 289
-#define K_START 290
-#define K_START_ARCHIVE 291
-#define K_START_CONFIG 292
-#define K_TABLE 293
-#define K_TO 294
-#define K_TRANSACTION 295
-#define K_UPDATE 296
-#define K_VACUUM 297
-#define K_VALUES 298
-#define K_WHERE 299
-#define T_COPYDATA 300
-#define T_COPYDATA_PART 301
-#define T_COPYEND 302
-#define T_IDENT 303
-#define T_LITERAL 304
-#define T_LITERAL_PART 305
-#define T_NUMBER 306
-#define T_TRACKING_FUNCTION 307
-#define T_FINISH_FUNCTION 308
-#define T_SEQSETVAL_FUNCTION 309
-#define T_PGSETVAL_FUNCTION 310
+#define K_REPLICA 288
+#define K_SELECT 289
+#define K_SESSION_ROLE 290
+#define K_SET 291
+#define K_START 292
+#define K_START_ARCHIVE 293
+#define K_START_CONFIG 294
+#define K_TABLE 295
+#define K_TO 296
+#define K_TRANSACTION 297
+#define K_UPDATE 298
+#define K_VACUUM 299
+#define K_VALUES 300
+#define K_WHERE 301
+#define T_COPYDATA 302
+#define T_COPYDATA_PART 303
+#define T_COPYEND 304
+#define T_IDENT 305
+#define T_LITERAL 306
+#define T_LITERAL_PART 307
+#define T_NUMBER 308
+#define T_TRACKING_FUNCTION 309
+#define T_FINISH_FUNCTION 310
+#define T_SEQSETVAL_FUNCTION 311
+#define T_PGSETVAL_FUNCTION 312
 
 
 
@@ -156,8 +158,8 @@
 typedef union YYSTYPE
 {
 
-/* Line 1676 of yacc.c  */
-#line 36 "parser.y"
+/* Line 2068 of yacc.c  */
+#line 38 "parser.y"
 
 	int32		ival;
 	char	   *str;
@@ -167,8 +169,8 @@ typedef union YYSTYPE
 
 
 
-/* Line 1676 of yacc.c  */
-#line 172 "y.tab.h"
+/* Line 2068 of yacc.c  */
+#line 174 "y.tab.h"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
