@@ -3,6 +3,8 @@
 # Author: Christopher Browne
 # Copyright 2004-2009 Afilias Canada
 
+use POSIX;
+
 sub add_node {
   my %PARAMS = (host=> undef,
 		dbname => 'template1',
@@ -132,14 +134,17 @@ sub start_slon {
   my ($nodenum) = @_;
   my ($dsn, $dbname) = ($DSN[$nodenum], $DBNAME[$nodenum]);
   $SYNC_CHECK_INTERVAL ||= 1000;
+  $DEBUGLEVEL ||= 0;
+  $LOG_NAME_SUFFIX ||= '%Y-%m-%d';
   system("mkdir -p $LOGDIR/slony1/node$nodenum");
-  my $cmd = "@@SLONBINDIR@@/slon -s $SYNC_CHECK_INTERVAL -d2 $CLUSTER_NAME '$dsn' 2>&1 ";
+  my $cmd = "@@SLONBINDIR@@/slon -s $SYNC_CHECK_INTERVAL -d$DEBUGLEVEL $CLUSTER_NAME '$dsn' ";
+  my $logfilesuffix = POSIX::strftime( "$LOG_NAME_SUFFIX",localtime );
+  chomp $logfilesuffix;
+
   if ($APACHE_ROTATOR) {
-    $cmd .= "| $APACHE_ROTATOR \"$LOGDIR/slony1/node$nodenum/" .  $dbname . "_%Y-%m-%d_%H:%M:%S.log\" 10M &";
+    $cmd .= "2>&1 | $APACHE_ROTATOR \"$LOGDIR/slony1/node$nodenum/" .  $dbname . "_$logfilesuffix.log\" 10M &";
   } else {
-    my $now=`date '+%Y-%m-%d_%H:%M:%S'`;
-    chomp $now;
-    $cmd .= "> $LOGDIR/slony1/node$nodenum/$dbname-$now.log &";
+    $cmd .= "> $LOGDIR/slony1/node$nodenum/$dbname-$logfilesuffix.log 2>&1 &";
   }
   print "Invoke slon for node $nodenum - $cmd\n";
   system ($cmd);
@@ -241,10 +246,18 @@ sub get_set {
     $SEQUENCE_ID  = $match->{"sequence_id"};
     @PKEYEDTABLES = @{$match->{"pkeyedtables"}};
     %KEYEDTABLES  = %{$match->{"keyedtables"}};
-    @SERIALTABLES = @{$match->{"serialtables"}};
     @SEQUENCES    = @{$match->{"sequences"}};
     $FOLD_CASE    = ($match->{"foldCase"} or 0);
 
+	if(defined($match->{"serialtables"}) &&
+	   scalar(@{$match->{"serialtables"}}) > 0 ) {
+		   # slony generated primary keys have
+		   # been deprecated.
+		   #
+		die "primary keys generated by slony (serialtables) are no longer "
+			. "supported by slony-I. Please remove serialtables"
+			.  "from your config file";
+	}
     return $match->{"set_id"};
 }
 
